# CHANGELOG

## 0.2.0

### Features

* Add support for matcher generators (syntax is directly bound to lambdas)
* Add support for conditional matcher using lambdas
* Add support for regex matchers
* Add support for range matchers

## 0.1.0

Initial version of `iguala`:

### Features

* support for matching literals
* support for matching objects
* support for matching dictionary
* support for paths
    * direct
    * recursive
* support for negative matcher (first implementation)
* support for wildcards
* support for wildcards for sequences
* first version of documentation (in `README.md`)